%% Variable processing
clear;
syms a b;
c=[a,b]';                                                                  % Composition Matrix
%% Input data processing
Data=[0.321 0.714 2.135 4.76 5.312 5.005];                                            % Enter data, which can be modified
Ly=cumsum(Data);                                                          
n=length(Data);                                                            % Number of original data
for k=1:(n-1)
    D(k)=(Ly(k)+Ly(k+1))/2;                                                % D(i) is the immediate neighbourhood mean generating sequence of xi(1)
end
%% Calculation of parameters using the mathematical principles of Grey Model
Vector =Data;                                                              % Vector is a vector of constant terms
Vector(1)=[];                                                              % Starting from the second number，x(2),x(3)...
Vector=Vector';
E=[-D;ones(1,n-1)]';                                                       % Cumulative generation of data for averaging
c=(E'*E)\(E'*Vector);                                                      % Use the formula to find a, b
c= c';
a=c(1);                                                                    % Get the value of a
b=c(2);                                                                    % Get the value of b
%% Obtain the Grey Model equation
F=[];
F(1)=Data(1);
for k=2:(n)
    F(k)=(Data(1)-b/a)/exp(a*(k-1))+b/a;                                   
end
%% Data restoration
G=[];
G(1)=Data(1);
for k=2:(n)
    G(k)=F(k)-F(k-1);                                                      % Get predicted data
end
%% Draw a curve of true and predicted values
t1=1:n;
t2=1:n;
t3=[3 4 6 8 10 12];
plot(t3,Data,'b*-');
hold on;
plot(t3,G,'ro--');
title('Predicted results');
legend('Real values','Predicted values');
xlabel('Time/h');
ylabel('d[AU]/dt');
%% Post-test difference test
e=Data-G;
q=e/Data;                                                                  % Relative errors
s1=var(Data);
s2=var(e);
c=s2/s1;                                                                   % Variance ratio
len=length(e);
p=0;                                                                       % Small error probability
for i=1:len
    if(abs(e(i))<0.6745*s1)
        p=p+1;
    end
end
p=p/len;
